==> pw-iso20022-SRU2023-9.4.7-sources.jar: com/prowidesoftware/swift/model/mx/dic/SettlementParties9.java <==

package com.prowidesoftware.swift.model.mx.dic;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.commons.lang3.builder.EqualsBuilder;
import org.apache.commons.lang3.builder.HashCodeBuilder;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;


/**
 * Identification of a settlement party by a choice between a BIC or a name and address.
 * 
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SettlementParties9", propOrder = {
    "dlvryAgt",
    "intrmy",
    "rcvgAgt",
    "bnfcryInstn"
})
public class SettlementParties9 {

    @XmlElement(name = "DlvryAgt")
    protected PartyIdentification19Choice dlvryAgt;
    @XmlElement(name = "Intrmy")
    protected PartyIdentification19Choice intrmy;
    @XmlElement(name = "RcvgAgt", required = true)
    protected PartyIdentification19Choice rcvgAgt;
    @XmlElement(name = "BnfcryInstn")
    protected PartyIdentification19Choice bnfcryInstn;

    /**
     * Gets the value of the dlvryAgt property.
     * 
     * @return
     *     possible object is
     *     {@link PartyIdentification19Choice }
     *     
     */
    public PartyIdentification19Choice getDlvryAgt() {
        return dlvryAgt;
    }

    /**
     * Sets the value of the dlvryAgt property.
     * 
     * @param value
     *     allowed object is
     *     {@link PartyIdentification19Choice }
     *     
     */
    public SettlementParties9 setDlvryAgt(PartyIdentification19Choice value) {
        this.dlvryAgt = value;
        return this;
    }

    /**
     * Gets the value of the intrmy property.
     * 
     * @return
     *     possible object is
     *     {@link PartyIdentification19Choice }
     *     
     */
    public PartyIdentification19Choice getIntrmy() {
        return intrmy;
    }

    /**
     * Sets the value of the intrmy property.
     * 
     * @param value
     *     allowed object is
     *     {@link PartyIdentification19Choice }
     *     
     */
    public SettlementParties9 setIntrmy(PartyIdentification19Choice value) {
        this.intrmy = value;
        return this;
    }

    /**
     * Gets the value of the rcvgAgt property.
     * 
     * @return
     *     possible object is
     *     {@link PartyIdentification19Choice }
     *     
     */
    public PartyIdentification19Choice getRcvgAgt() {
        return rcvgAgt;
    }

    /**
     * Sets the value of the rcvgAgt property.
     * 
     * @param value
     *     allowed object is
     *     {@link PartyIdentification19Choice }
     *     
     */
    public SettlementParties9 setRcvgAgt(PartyIdentification19Choice value) {
        this.rcvgAgt = value;
        return this;
    }

    /**
     * Gets the value of the bnfcryInstn property.
     * 
     * @return
     *     possible object is
     *     {@link PartyIdentification19Choice }
     *     
     */
    public PartyIdentification19Choice getBnfcryInstn() {
        return bnfcryInstn;
    }

    /**
     * Sets the value of the bnfcryInstn property.
     * 
     * @param value
     *     allowed object is
     *     {@link PartyIdentification19Choice }
     *     
     */
    public SettlementParties9 setBnfcryInstn(PartyIdentification19Choice value) {
        this.bnfcryInstn = value;
        return this;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this, ToStringStyle.MULTI_LINE_STYLE);
    }

    @Override
    public boolean equals(Object that) {
        return EqualsBuilder.reflectionEquals(this, that);
    }

    @Override
    public int hashCode() {
        return HashCodeBuilder.reflectionHashCode(this);
    }

}

==> pw-iso20022-SRU2024-10.2.9-sources.jar: com/prowidesoftware/swift/model/mx/dic/SettlementParties9.java <==

package com.prowidesoftware.swift.model.mx.dic;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;
import org.apache.commons.lang3.builder.EqualsBuilder;
import org.apache.commons.lang3.builder.HashCodeBuilder;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;


/**
 * Identification of a settlement party by a choice between a BIC or a name and address.
 * 
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SettlementParties9", propOrder = {
    "dlvryAgt",
    "intrmy",
    "rcvgAgt",
    "bnfcryInstn"
})
public class SettlementParties9 {

    @XmlElement(name = "DlvryAgt")
    protected PartyIdentification19Choice dlvryAgt;
    @XmlElement(name = "Intrmy")
    protected PartyIdentification19Choice intrmy;
    @XmlElement(name = "RcvgAgt", required = true)
    protected PartyIdentification19Choice rcvgAgt;
    @XmlElement(name = "BnfcryInstn")
    protected PartyIdentification19Choice bnfcryInstn;

    /**
     * Gets the value of the dlvryAgt property.
     * 
     * @return
     *     possible object is
     *     {@link PartyIdentification19Choice }
     *     
     */
    public PartyIdentification19Choice getDlvryAgt() {
        return dlvryAgt;
    }

    /**
     * Sets the value of the dlvryAgt property.
     * 
     * @param value
     *     allowed object is
     *     {@link PartyIdentification19Choice }
     *     
     */
    public SettlementParties9 setDlvryAgt(PartyIdentification19Choice value) {
        this.dlvryAgt = value;
        return this;
    }

    /**
     * Gets the value of the intrmy property.
     * 
     * @return
     *     possible object is
     *     {@link PartyIdentification19Choice }
     *     
     */
    public PartyIdentification19Choice getIntrmy() {
        return intrmy;
    }

    /**
     * Sets the value of the intrmy property.
     * 
     * @param value
     *     allowed object is
     *     {@link PartyIdentification19Choice }
     *     
     */
    public SettlementParties9 setIntrmy(PartyIdentification19Choice value) {
        this.intrmy = value;
        return this;
    }

    /**
     * Gets the value of the rcvgAgt property.
     * 
     * @return
     *     possible object is
     *     {@link PartyIdentification19Choice }
     *     
     */
    public PartyIdentification19Choice getRcvgAgt() {
        return rcvgAgt;
    }

    /**
     * Sets the value of the rcvgAgt property.
     * 
     * @param value
     *     allowed object is
     *     {@link PartyIdentification19Choice }
     *     
     */
    public SettlementParties9 setRcvgAgt(PartyIdentification19Choice value) {
        this.rcvgAgt = value;
        return this;
    }

    /**
     * Gets the value of the bnfcryInstn property.
     * 
     * @return
     *     possible object is
     *     {@link PartyIdentification19Choice }
     *     
     */
    public PartyIdentification19Choice getBnfcryInstn() {
        return bnfcryInstn;
    }

    /**
     * Sets the value of the bnfcryInstn property.
     * 
     * @param value
     *     allowed object is
     *     {@link PartyIdentification19Choice }
     *     
     */
    public SettlementParties9 setBnfcryInstn(PartyIdentification19Choice value) {
        this.bnfcryInstn = value;
        return this;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this, ToStringStyle.MULTI_LINE_STYLE);
    }

    @Override
    public boolean equals(Object that) {
        return EqualsBuilder.reflectionEquals(this, that);
    }

    @Override
    public int hashCode() {
        return HashCodeBuilder.reflectionHashCode(this);
    }

}
